@@ -6,14 +6,21 @@ from requests.models import Response
 def test_simple_sorting(client: TestClient, users, generate_data):
     response: Response = client.get("/users?sort=age")
     assert response.status_code == status.HTTP_200_OK
-    assert response.json() == {"data": [generate_data(user) for user in sorted(users, key=lambda user: user.age)]}
+    assert response.json() == {
+        "data": [
+            generate_data(user) for user in sorted(users, key=lambda user: user.age)
+        ]
+    }
 
 
 def test_simple_sorting_desc(client: TestClient, users, generate_data):
     response: Response = client.get("/users?sort=-age")
     assert response.status_code == status.HTTP_200_OK
     assert response.json() == {
-        "data": [generate_data(user) for user in sorted(users, key=lambda user: user.age, reverse=True)]
+        "data": [
+            generate_data(user)
+            for user in sorted(users, key=lambda user: user.age, reverse=True)
+        ]
     }
 
 
@@ -21,7 +28,10 @@ def test_sorting_multiple_fields(client: TestClient, users, generate_data):
     response: Response = client.get("/users?sort=age,name")
     assert response.status_code == status.HTTP_200_OK
     assert response.json() == {
-        "data": [generate_data(user) for user in sorted(users, key=lambda user: (user.age, user.name))]
+        "data": [
+            generate_data(user)
+            for user in sorted(users, key=lambda user: (user.age, user.name))
+        ]
     }
 
 
@@ -29,5 +39,15 @@ def test_sorting_multiple_fields_desc(client: TestClient, users, generate_data):
     response: Response = client.get("/users?sort=-age,name")
     assert response.status_code == status.HTTP_200_OK
     assert response.json() == {
-        "data": [generate_data(user) for user in sorted(users, key=lambda user: (user.age, user.name), reverse=True)]
+        "data": [
+            generate_data(user)
+            for user in sorted(
+                users, key=lambda user: (user.age, user.name), reverse=True
+            )
+        ]
     }
+
+
+def test_sorting_non_existing_field(client: TestClient, users, generate_data):
+    response: Response = client.get("/users?sort=foobar")
+    assert response.status_code == status.HTTP_500_INTERNAL_SERVER_ERROR
